@@ -71,6 +71,7 @@ from .models.fbnet import *
 from .models.xception import *
 from .models.inceptionv3 import *
 from .models.inceptionv4 import *
+from .models.inceptionresnetv1 import *
 from .models.inceptionresnetv2 import *
 from .models.polynet import *
 from .models.nasnet import *
@@ -156,6 +157,8 @@ from .models.jasper import *
 from .models.jasperdr import *
 from .models.quartznet import *
 
+# from .models.others.oth_quartznet import *
+
 # from .models.others.oth_pose_resnet import *
 # from .models.others.oth_lwopenpose2d import *
 # from .models.others.oth_lwopenpose3d import *
@@ -651,6 +654,7 @@ _models = {
     'xception': xception,
     'inceptionv3': inceptionv3,
     'inceptionv4': inceptionv4,
+    'inceptionresnetv1': inceptionresnetv1,
     'inceptionresnetv2': inceptionresnetv2,
     'polynet': polynet,
 
@@ -1155,13 +1159,34 @@ _models = {
     'jasper10x4': jasper10x4,
     'jasper10x5': jasper10x5,
 
-    'jasperdr5x3': jasperdr5x3,
-    'jasperdr10x4': jasperdr10x4,
-    'jasperdr10x5': jasperdr10x5,
+    'jasperdr10x5_en': jasperdr10x5_en,
+    'jasperdr10x5_en_nr': jasperdr10x5_en_nr,
 
-    'quartznet5x5': quartznet5x5,
-    'quartznet10x5': quartznet10x5,
-    'quartznet15x5': quartznet15x5,
+    'quartznet5x5_en_ls': quartznet5x5_en_ls,
+    'quartznet15x5_en': quartznet15x5_en,
+    'quartznet15x5_en_nr': quartznet15x5_en_nr,
+    'quartznet15x5_fr': quartznet15x5_fr,
+    'quartznet15x5_de': quartznet15x5_de,
+    'quartznet15x5_it': quartznet15x5_it,
+    'quartznet15x5_es': quartznet15x5_es,
+    'quartznet15x5_ca': quartznet15x5_ca,
+    'quartznet15x5_pl': quartznet15x5_pl,
+    'quartznet15x5_ru': quartznet15x5_ru,
+    'quartznet15x5_ru34': quartznet15x5_ru34,
+
+    # 'oth_quartznet5x5_en_ls': oth_quartznet5x5_en_ls,
+    # 'oth_quartznet15x5_en': oth_quartznet15x5_en,
+    # 'oth_quartznet15x5_en_nr': oth_quartznet15x5_en_nr,
+    # 'oth_quartznet15x5_fr': oth_quartznet15x5_fr,
+    # 'oth_quartznet15x5_de': oth_quartznet15x5_de,
+    # 'oth_quartznet15x5_it': oth_quartznet15x5_it,
+    # 'oth_quartznet15x5_es': oth_quartznet15x5_es,
+    # 'oth_quartznet15x5_ca': oth_quartznet15x5_ca,
+    # 'oth_quartznet15x5_pl': oth_quartznet15x5_pl,
+    # 'oth_quartznet15x5_ru': oth_quartznet15x5_ru,
+    # 'oth_jasperdr10x5_en': oth_jasperdr10x5_en,
+    # 'oth_jasperdr10x5_en_nr': oth_jasperdr10x5_en_nr,
+    # 'oth_quartznet15x5_ru34': oth_quartznet15x5_ru34,
 
     # 'oth_pose_coco_resnet_50_256x192': oth_pose_coco_resnet_50_256x192,
     # 'oth_pose_coco_resnet_50_384x288': oth_pose_coco_resnet_50_384x288,
